==> haskell-yesod-static-1.6.1.0-900-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-l1jYfdMKtXHr3SCuEXhMc
key:                  yesod-static-1.6.1.0-l1jYfdMKtXHr3SCuEXhMc
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  76c97bd06af609a7c69b8e3d1120ad25
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-l1jYfdMKtXHr3SCuEXhMc
depends:
    async-2.2.5-8qrDbV8xcFXEsDmo0VTM7z
    attoparsec-0.14.4-H9Y4iLHDqcP1CPr5BByOUl base-4.17.2.1
    base64-bytestring-1.2.1.0-G53UOvB3pKB2mwL6yBWItW
    blaze-builder-0.4.4-J87LvVgADYa5gww986bADm bytestring-0.11.5.3
    conduit-1.3.6.1-KngnZK76tgfFFxoV5CBnAq containers-0.6.7
    cryptonite-0.30-H1cQVodLmPgIbDxMrxNPVu
    cryptonite-conduit-0.2.2-KCPyRUR1jl89BFzMJzD2rv
    css-text-0.1.3.0-FU6Fbdhf6eR5AWo0q9nRKC
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.4.0-5SoCNaysfySGuPwu0aljBu
    hjsmin-0.2.1-CJk4CVF4UyZIemoyycrpeF
    http-types-0.12.4-J468GPAKalzFHPyn7Dxh3c
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-ISYORPhqblp3hlkoU2fe45
    unordered-containers-0.2.20-AeV3HTkHtCc6BQ9fzLSSB8
    wai-3.2.4-9Kksr2P6n2618XIJvAeWn8
    wai-app-static-3.1.9-B9so7PsRzT83w4EEf4Dfef
    yesod-core-1.6.27.1-GNPlyEXjziV5Qk3e6SPURR

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-901-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-B8TSY1XYvAMQsGwsEi9gi
key:                  yesod-static-1.6.1.0-B8TSY1XYvAMQsGwsEi9gi
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  3e4e860903fa21205b5a71f1af00287e
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-B8TSY1XYvAMQsGwsEi9gi
depends:
    async-2.2.5-EKzjtytxFSDGO33P7IPwKj
    attoparsec-0.14.4-7XWZ3nsZOGKJDEorzXp6qF base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb
    blaze-builder-0.4.4-EYzzAuOKf5mlUrLaPwbAW bytestring-0.11.5.3
    conduit-1.3.6.1-FwwHGMHw6pcBHMWck7Ofs9 containers-0.6.7
    cryptonite-0.30-LOJw8RwfFXQ8B7BPABeHay
    cryptonite-conduit-0.2.2-HMBg337sgPUF2PJsTMy0KA
    css-text-0.1.3.0-LpwK4OGQ5WjIaeUlpUJrDk
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    hjsmin-0.2.1-By5nf5EWE1XJq2DskBGSKg
    http-types-0.12.4-JotGc98QwUtHuX8PPdlxoe
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq process-1.6.18.0
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2
    unix-compat-0.7.4.1-GSBAQpPSas81W7oazsVVV
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r
    wai-3.2.4-Jw3By0RvhPE8QsBvrL71Dx
    wai-app-static-3.1.9-DCEfmZAx3n89LJS2ESjTXy
    yesod-core-1.6.27.1-AvkgIJCPGp4EoSYdWjMPG4

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
